@@ -33,7 +33,9 @@ def copytree(src, dst, symlinks=0, allowed_basenames=None, exclude=[]):
         if ext == ".egg-info":
             continue
         srcname = os.path.join(src, name)
+        srcname = os.path.normpath(srcname)
         dstname = os.path.join(dst, name)
+        dstname = os.path.normpath(dstname)
         if allowed_basenames:
             if os.path.isfile(srcname):
                 if name not in allowed_basenames:
@@ -41,6 +43,13 @@ def copytree(src, dst, symlinks=0, allowed_basenames=None, exclude=[]):
                     continue
         if os.path.basename(srcname) in exclude:
             continue
+        matched = False
+        for pattern in exclude:
+            if re.match(pattern, srcname):
+                matched = True
+                break
+        if matched:
+            continue
         try:
             if symlinks and os.path.islink(srcname):
                 linkto = os.readlink(srcname)
